Binary Serialization Formats
============================

Handlers for binary serialization and interchange formats.

.. autosummary::
   :toctree: generated

   etlplus.file.avro
   etlplus.file.bson
   etlplus.file.cbor
   etlplus.file.ion
   etlplus.file.msgpack
   etlplus.file.pb
   etlplus.file.pbf
   etlplus.file.proto
